@@ -1,4 +1,4 @@
-import { DataTypes, Sequelize } from 'sequelize';
+import { DataTypes } from 'sequelize';
 
 import { SYNC_DIRECTIONS } from '@tamanu/constants';
 
@@ -18,6 +18,9 @@ export class ChangeLog extends Model {
   declare recordUpdatedAt: Date;
   declare recordDeletedAt: Date | null;
   declare recordData: string;
+  declare deviceId: string;
+  declare version: string;
+  declare reason: string | null;
 
   static initModel({ primaryKey, ...options }: InitOptions) {
     super.init(
@@ -38,7 +41,6 @@ export class ChangeLog extends Model {
         loggedAt: {
           type: DataTypes.DATE,
           allowNull: false,
-          defaultValue: Sequelize.fn('adjusted_timestamp'),
         },
         updatedByUserId: {
           type: DataTypes.TEXT,
@@ -64,6 +66,18 @@ export class ChangeLog extends Model {
           type: DataTypes.JSONB,
           allowNull: false,
         },
+        deviceId: {
+          type: DataTypes.TEXT,
+          allowNull: false,
+        },
+        version: {
+          type: DataTypes.TEXT,
+          allowNull: false,
+        },
+        reason: {
+          type: DataTypes.TEXT,
+          allowNull: true,
+        },
       },
 
       {
